@@ -3,7 +3,7 @@ import re
 import sys
 
 from .job import Job  # noqa
-from .run import run, run_by_cron  # noqa
+from .run import run, run_by_cron, run_periodically  # noqa
 
 try:
     import aiohttp  # noqa
@@ -13,7 +13,7 @@ except ImportError:
     pass
 
 
-__version__ = "0.0.2"
+__version__ = "0.0.3"
 
 version = f"{__version__}, Python {sys.version}"
 
